pub enum LineWrapping {
Preserve,
Unwrap,
}Expand description
Configuration for soft line breaks in phrasing content.
Variants
Preserve
Preserve soft line breaks from the syntax tree (the default).
Unwrap
Replace soft line breaks with spaces.
Explicit Markdown hard breaks, code, and block boundaries are preserved.