pub enum AlignKind {
Left,
Right,
Center,
None,
}Expand description
GFM: alignment of phrasing content.
Used to align the contents of table cells within a table.
Variants
Left
Left alignment.
See the left value of the text-align CSS property.
| | aaa |
> | | :-- |
^^^Right
Right alignment.
See the right value of the text-align CSS property.
| | aaa |
> | | --: |
^^^Center
Center alignment.
See the center value of the text-align CSS property.
| | aaa |
> | | :-: |
^^^None
No alignment.
Phrasing content is aligned as defined by the host environment.
| | aaa |
> | | --- |
^^^Trait Implementations
impl Copy for AlignKind
impl Eq for AlignKind
impl StructuralPartialEq for AlignKind