pub struct Image {
pub position: Option<Position>,
pub alt: String,
pub url: String,
pub title: Option<String>,
}Expand description
Image.
> | 
^^^^^^^Fields
position: Option<Position>Positional info.
alt: StringEquivalent content for environments that cannot represent the node as intended.
url: StringURL to the referenced resource.
title: Option<String>Advisory info for the resource, such as something that would be appropriate for a tooltip.