pub struct InlineCode {
pub value: String,
pub position: Option<Position>,
pub lang: Option<String>,
}Expand description
Code (phrasing).
> | `a`
^^^Fields
value: StringContent model.
position: Option<Position>Positional info.
lang: Option<String>Optional language identifier parsed from an inline code prefix.
This is a Socketry Markdown extension; standard mdast inline code nodes do not have a language field.