pub struct Point {
pub line: usize,
pub column: usize,
pub offset: usize,
}Expand description
One place in a source file.
Fields
line: usize1-indexed integer representing a line in a source file.
column: usize1-indexed integer representing a column in a source file.
offset: usize0-indexed integer representing a character in a source file.
Implementations