pub struct Position {
pub start: Point,
pub end: Point,
}Expand description
Location of a node in a source file.
Fields
start: PointRepresents the place of the first character of the parsed source region.
end: PointRepresents the place of the first character after the parsed source region, whether it exists or not.
Implementations