pub struct Options {Show 18 fields
pub bullet: char,
pub bullet_ordered: char,
pub bullet_other: char,
pub close_atx: bool,
pub emphasis: char,
pub fence: char,
pub fences: bool,
pub increment_list_marker: bool,
pub list_item_indent: IndentOptions,
pub quote: char,
pub resource_link: bool,
pub rule: char,
pub rule_repetition: u32,
pub rule_spaces: bool,
pub setext: bool,
pub single_dollar_text_math: bool,
pub strong: char,
pub tight_definitions: bool,
}Expand description
Configuration.
Fields
bullet: charMarker to use for bullets of items in unordered lists ('*', '+', or
'-', default: '*').
bullet_ordered: charMarker to use for bullets of items in ordered lists ('.' or ')',
default: '.').
bullet_other: charMarker to use in certain cases where the primary bullet doesn’t work
('*', '+', or '-', default: '-' when bullet is '*', '*'
otherwise).
close_atx: boolWhether to add the same number of number signs (#) at the end of an
ATX heading as the opening sequence (bool, default: false).
emphasis: charMarker to use for emphasis ('*' or '_', default: '*').
fence: charMarker to use for fenced code ('`' or '~', default: '`').
fences: boolWhether to use fenced code always (bool, default: true).
The default is to use fenced code if there is a language defined,
if the code is empty,
or if it starts or ends in blank lines.
increment_list_marker: boolWhether to increment the counter of ordered lists items (bool,
default: true).
list_item_indent: IndentOptionsHow to indent the content of list items (default: IndentOptions::One).
quote: charMarker to use for titles ('"' or "'", default: '"').
resource_link: boolWhether to always use resource links (bool, default: false).
The default is to use autolinks (<https://example.com>) when possible
and resource links ([text](url)) otherwise.
rule: charMarker to use for thematic breaks ('*', '-', or '_', default:
'*').
rule_repetition: u32Number of markers to use for thematic breaks (u32, default: 3, min:
3).
rule_spaces: boolWhether to add spaces between markers in thematic breaks (bool,
default: false).
setext: boolWhether to use setext headings when possible (bool, default:
false).
The default is to always use ATX headings (# heading) instead of
setext headings (heading\n=======).
Setext headings cannot be used for empty headings or headings with a
rank of three or more.
single_dollar_text_math: boolWhether to support math (text) with a single dollar (bool, default: true).
Single dollars work in Pandoc and many other places, but often interfere with “normal”
dollars in text.
If you turn this off, you can still use two or more dollars for text math.
strong: charMarker to use for strong ('*' or '_', default: '*').
tight_definitions: boolWhether to join definitions without a blank line (bool, default:
false).